@@ -2,9 +2,9 @@ package Term::Choose;
 
 use warnings;
 use strict;
-use 5.10.0;
+use 5.10.1;
 
-our $VERSION = '1.768';
+our $VERSION = '1.774';
 use Exporter 'import';
 our @EXPORT_OK = qw( choose );
 
@@ -742,8 +742,9 @@ sub __prepare_info_and_prompt_lines {
         my $subseq   = $self->{tabs_info}[1] // 0;
         my $r_margin = $self->{tabs_info}[2] // 0;
         push @tmp_prompt, line_fold(
-            $self->{info}, $info_w - $r_margin,
-            { init_tab => ' ' x $init, subseq_tab => ' ' x $subseq, color => $self->{color}, join => 0 }
+            $self->{info},
+            { width => $info_w - $r_margin, init_tab => ' ' x $init, subseq_tab => ' ' x $subseq,
+              color => $self->{color}, join => 0 }
         );
     }
     if ( length $self->{prompt} ) {
@@ -751,8 +752,9 @@ sub __prepare_info_and_prompt_lines {
         my $subseq   = $self->{tabs_prompt}[1] // 0;
         my $r_margin = $self->{tabs_prompt}[2] // 0;
         push @tmp_prompt, line_fold(
-            $self->{prompt}, $info_w - $r_margin,
-            { init_tab => ' ' x $init, subseq_tab => ' ' x $subseq, color => $self->{color}, join => 0 }
+            $self->{prompt},
+            { width => $info_w - $r_margin, init_tab => ' ' x $init, subseq_tab => ' ' x $subseq,
+              color => $self->{color}, join => 0 }
         );
     }
     if ( length $self->{search_info} ) {
@@ -1278,7 +1280,7 @@ Term::Choose - Choose items from a list interactively.
 
 =head1 VERSION
 
-Version 1.768
+Version 1.774
 
 =cut
 
@@ -1898,10 +1900,15 @@ list context.
 
 =head2 Perl version
 
-Requires Perl version 5.10.0 or greater.
+Requires Perl version 5.10.1 or higher.
 
 =head2 Optional modules
 
+=head3 Term::Choose::LineFold::XS
+
+If L<Term::Choose::LineFold::XS> is installed, its functions will be used automatically in place of the pure-Perl
+implementations, providing faster performance. C<Term::Choose::LineFold::XS> requires Perl version 5.16.0 or higher.
+
 =head3 Term::ReadKey
 
 If L<Term::ReadKey> is available it is used C<ReadKey> to read the user input and C<GetTerminalSize> to get the
@@ -1923,8 +1930,10 @@ It is required a terminal that uses a monospaced font which supports the printed
 
 =head2 Ambiguous width characters
 
-By default ambiguous width characters are treated as half width. If the environment variable C<TC_AMBIGUOUS_WIDE> is set
-to a true value, ambiguous width characters are treated as full width.
+By default ambiguous width characters are treated as half width. If the environment variable
+C<TC_AMBIGUOUS_WIDTH_IS_WIDE> is set to a true value, ambiguous width characters are treated as full width.
+
+The support for the old variable name C<TC_AMBIGUOUS_WIDE> will be removed.
 
 =head2 Escape sequences
 
